<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>О программе %1</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Seafile Drive Client %2&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Seafile Drive Client %2&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation>&lt;h5&gt; REV %1 &lt;/h5&gt;</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>Не удалось открыть базу данных аккаунтов</translation>
    </message>
</context>
<context>
    <name>AutoLogonDialog</name>
    <message>
        <source>auto login</source>
        <translation>автоматический вход</translation>
    </message>
    <message>
        <source>auto logining, please wait a moment</source>
        <translation>автоматический вход, пожалуйста, подождите</translation>
    </message>
    <message>
        <source>Please input server address</source>
        <translation>Введите адрес сервера</translation>
    </message>
    <message>
        <source>address</source>
        <translation>адрес</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Введите адрес сервера</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 неправильный адрес сервера</translation>
    </message>
    <message>
        <source>login failed</source>
        <translation>не удалось войти</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>%1 failed to initialize</source>
        <translation>%1 ошибка инициализации</translation>
    </message>
    <message>
        <source>%1 exited unexpectedly</source>
        <translation>%1 неожиданно вышел</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create seadrive mount folder</source>
        <translation>Не удалось инициализировать: не удалось создать папку для подключения seadrive</translation>
    </message>
</context>
<context>
    <name>EncryptedReposDialog</name>
    <message>
        <source>Encrypted Libraries</source>
        <translation>Зашифрованные библиотеки</translation>
    </message>
    <message>
        <source>No Encrypted Library.</source>
        <translation>Нет зашифрованных библиотек.</translation>
    </message>
</context>
<context>
    <name>EncryptedReposTableModel</name>
    <message>
        <source>Failed to set encrypted library password</source>
        <translation>Не удалось установить пароль зашифрованной библиотеки</translation>
    </message>
    <message>
        <source>Password error</source>
        <translation>Ошибка пароля</translation>
    </message>
    <message>
        <source>Failed to clear encrypted library password</source>
        <translation>Не удалось удалить пароль зашифрованной библиотеки</translation>
    </message>
    <message>
        <source>Right click this item to sync or unsync the encrypted library</source>
        <translation>Щелкните правой кнопкой мыши этот элемент, чтобы синхронизировать или отменить синхронизацию зашифрованной библиотеки</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <source>Sync status</source>
        <translation>Статус синхронизации</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Сервер</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
</context>
<context>
    <name>EncryptedReposTableView</name>
    <message>
        <source>Unsync</source>
        <translation>Не синхронизировано</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхронизировано</translation>
    </message>
    <message>
        <source>After unsyncing, the local encryption key of this library will be cleared and this library cannot be accessed in virtual drive. Are you sure to unsync?</source>
        <translation>После отмены синхронизации локальный ключ шифрования этой библиотеки будет удален, и эта библиотека не будет доступна на виртуальном диске. Вы уверены, что хотите отменить синхронизацию?</translation>
    </message>
    <message>
        <source>Enter library password to sync</source>
        <translation>Введите пароль библиотеки для синхронизации</translation>
    </message>
</context>
<context>
    <name>ExtCommandsHandler</name>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
        <translation>Вы уверены, что необходимо удалить учетную запись с &quot;%1&quot;? Скачанные и загружаемые файлы не будут удалены.</translation>
    </message>
    <message>
        <source>Failed to connect to background process, please try again later</source>
        <translation>Не удалось подключиться к фоновому процессу. Повторите попытку позже</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
        <translation>Вы уверены, что необходимо повторно синхронизировать учетную запись с &quot;%1&quot;? Скачанные и загружаемые файлы не будут удалены</translation>
    </message>
</context>
<context>
    <name>FileProviderManager</name>
    <message>
        <source>%1 will ask permissions to enable Finder plugin.</source>
        <translation>%1 запросит разрешения на включение плагина Finder.</translation>
    </message>
</context>
<context>
    <name>FilterMenu</name>
    <message>
        <source>FilterMenu</source>
        <translation>Фильтры</translation>
    </message>
    <message>
        <source>Text file    </source>
        <translation>Текстовый файл    </translation>
    </message>
    <message>
        <source>Document    </source>
        <translation>Документ    </translation>
    </message>
    <message>
        <source>Image    </source>
        <translation>Изображение    </translation>
    </message>
    <message>
        <source>Video    </source>
        <translation>Видео    </translation>
    </message>
    <message>
        <source>Audio    </source>
        <translation>Аудио    </translation>
    </message>
    <message>
        <source>Markdown</source>
        <translation>Markdown</translation>
    </message>
</context>
<context>
    <name>InitSyncDialog</name>
    <message>
        <source>Download files list</source>
        <translation>Загрузка списка файлов</translation>
    </message>
    <message>
        <source>%1 is fetching the files list, please wait</source>
        <translation>%1 получает список файлов, пожалуйста, ждите...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Окно</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>Логотип</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Запуск в фоновом режиме</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Завершить</translation>
    </message>
    <message>
        <source>%1 has downloaded your files list.</source>
        <translation>%1 скачал список файлов.</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation>показать еще</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Добавить учетную запись</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation>Единая точка входа</translation>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Войти заново</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Авторизуемся...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Сетевая ошибка:
%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Внимание:&lt;/b&gt; SSL-сертификат этого сервера не является доверенным. Продолжить несмотря на это?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Введите адрес сервера</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 неправильный адрес сервера</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Введите имя пользователя</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Пожалуйста, введите имя компьютера</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation>Двухфакторная аутентификация</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation>%1 Адрес сервера</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Введите пароль</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation>Введите ключ двухфакторной аутентификации</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>Неверный email или пароль</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Слишком частые попытки входа. Пожалуйста, подождите минуту</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Внутренняя ошибка сервера</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Не удалось авторизоваться: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Не удалось авторизоваться</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Диалог</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>Логотип</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Сервер:</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>или http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>Automatic Login</source>
        <translation>Автоматический вход</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>текст статуса</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Имя Компьютера: </translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation>Email / Имя пользователя:</translation>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>например, ноутбук Ивана</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Войти</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Failed to get server info. Please check the server address.</source>
        <translation>Не удалось получить информацию о сервере. Проверьте адрес сервера.</translation>
    </message>
    <message>
        <source>Failed to get client sso link.</source>
        <translation>Не удалось получить ссылку единого входа клиента.</translation>
    </message>
    <message>
        <source>SSO login failed.</source>
        <translation>Не удалось войти в систему единого входа.</translation>
    </message>
    <message>
        <source>Failed to get client sso status.</source>
        <translation>Не удалось получить статус единого входа клиента.</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Например: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation>Расширенные параметры</translation>
    </message>
    <message>
        <source>Sync Root Folder Name:</source>
        <translation>Имя корневой папки синхронизации:</translation>
    </message>
    <message>
        <source>Sync root folder name cannot be empty</source>
        <translation>Имя корневой папки синхронизации не может быть пустым</translation>
    </message>
    <message>
        <source>Sync root folder name cannot contain the following characters: &lt; &gt; : &quot; / \ | ? *</source>
        <translation>Имя корневой папки синхронизации не может содержать следующие символы: &lt; &gt; : &quot; / \ | ? *</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Files in this account will be synced under the path like &apos;C:\Users\Jim\seadrive_root\&amp;lt;sync root folder name&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Файлы в этой учетной записи будут синхронизированы по пути, подобному &apos;C:\Users\Jim\seadrive_root\&amp;lt;имя корневой папки синхронизации&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MessagePoller</name>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>Синхронизация &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Error when syncing &quot;%1&quot;</source>
        <translation>Ошибка при синхронизации &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Error when syncing</source>
        <translation>Ошибка при синхронизации</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is being uploaded</source>
        <translation>&quot;%1&quot; загружается</translation>
    </message>
    <message>
        <source>Starting to move &quot;%1&quot;</source>
        <translation>Перемещение &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Starting to move &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Перемещение из &quot;%1&quot; в &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Successfully moved &quot;%1&quot;</source>
        <translation>Успешно перемещен &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Successfully moved &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Успешно перемещен из &quot;%1&quot; в &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Failed to move &quot;%1&quot;</source>
        <translation>Не удалось переместить &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to move &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Не удалось переместить из &quot;%1&quot; в &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Download file</source>
        <translation>Скачать файл</translation>
    </message>
    <message>
        <source>Start to download file &quot;%1&quot; </source>
        <translation>Начало загрузки файла &quot;%1&quot; </translation>
    </message>
    <message>
        <source>file &quot;%1&quot; has been downloaded </source>
        <translation>файл &quot;%1&quot; был загружен </translation>
    </message>
    <message>
        <source>Failed to create file &quot;%1&quot;</source>
        <translation>Не удалось создать файл &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to delete folder</source>
        <translation>Не удалось удалить папку</translation>
    </message>
    <message>
        <source>You can&apos;t delete the library &quot;%1&quot; directly</source>
        <translation>Вы не можете удалить библиотеку &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Libraries are ready</source>
        <translation>Библиотеки готовы</translation>
    </message>
    <message>
        <source>All libraries are loaded and ready to use.</source>
        <translation>Все библиотеки загружены и готовы к использованию.</translation>
    </message>
    <message>
        <source>Deleted &quot;%1&quot; and %2 more files.</source>
        <translation>Удалено &quot;%1&quot; и еще %2 файлов.</translation>
    </message>
    <message>
        <source>You can&apos;t create files in the mount folder directly</source>
        <translation>Вы не можете создавать файлы в папке монтирования напрямую</translation>
    </message>
    <message>
        <source>Do you want to delete files in library &quot;%1&quot; ?</source>
        <translation>Вы хотите удалить файлы в библиотеке &quot;%1&quot; ?</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Удалена библиотека &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Confirm to delete library &quot;%1&quot; ?</source>
        <translation>Подтвердить удаление библиотеки &quot;%1&quot; ?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>File %1 is locked by other programs</source>
        <translation>Файл %1 заблокирован другой программой</translation>
    </message>
    <message>
        <source>Some file is locked by other programs</source>
        <translation>Файл заблокирован другой программой</translation>
    </message>
    <message>
        <source>Folder %1 is locked by other programs</source>
        <translation>Папка %1 заблокирована в другой программе</translation>
    </message>
    <message>
        <source>Some folder is locked by other programs</source>
        <translation>Папка заблокирована в другой программе</translation>
    </message>
    <message>
        <source>File %1 is locked by another user</source>
        <translation>Файл %1 заблокирован другим пользователем</translation>
    </message>
    <message>
        <source>Some file is locked by another user</source>
        <translation>Файл заблокирован другим пользователем</translation>
    </message>
    <message>
        <source>Invalid path %1</source>
        <translation>Неверный путь %1</translation>
    </message>
    <message>
        <source>Trying to access an invalid path</source>
        <translation>Попытка доступа к неверному пути</translation>
    </message>
    <message>
        <source>Error when indexing file %1</source>
        <translation>Ошибка индексации файла %1</translation>
    </message>
    <message>
        <source>Error when indexing files</source>
        <translation>Ошибка индексации файлов</translation>
    </message>
    <message>
        <source>You don&apos;t have enough permission for this library</source>
        <translation>У вас нет доступа к этой библиотеки</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation>Ошибка сети</translation>
    </message>
    <message>
        <source>Failed to resolve network proxy</source>
        <translation>Не удалось разрешить сетевой прокси</translation>
    </message>
    <message>
        <source>Failed to resolve remote server</source>
        <translation>Не удалось разрешить удаленный сервер</translation>
    </message>
    <message>
        <source>Failed to connect to server</source>
        <translation>Не удалось подключиться к серверу</translation>
    </message>
    <message>
        <source>SSL error</source>
        <translation>Ошибка SSL</translation>
    </message>
    <message>
        <source>Error in network transmission</source>
        <translation>Ошибка при передаче по сети</translation>
    </message>
    <message>
        <source>Timeout in network transmission</source>
        <translation>Таймаут при передаче по сети</translation>
    </message>
    <message>
        <source>Failed to handle http redirection</source>
        <translation>Не удалось обработать http перенаправление</translation>
    </message>
    <message>
        <source>Server internal error</source>
        <translation>Внутренняя ошибка сервера</translation>
    </message>
    <message>
        <source>Local data is corrupt</source>
        <translation>Локальные данные повреждены</translation>
    </message>
    <message>
        <source>Failed to write local data</source>
        <translation>Не удалось записать локальные данные</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Неизвестная ошибка</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>Квота хранения была израсходована</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>Ошибка SSL</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Сетевая ошибка: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Ошибка сервера</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Создана библиотека &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Удалена библиотека &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Добавлен</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Удален</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Удален</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Изменен</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Переименован</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation>Добавлено или изменено</translation>
    </message>
    <message>
        <source>Moved</source>
        <translation>Перемещен</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Добавлена папка</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Удалена папка</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Переименованная папка</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Папка перемещена</translation>
    </message>
    <message>
        <source>files</source>
        <translation>файлы</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>папки</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>и еще %1</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Библиотека возвращена к статусу от</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>Файл &quot;%1&quot; возвращен к статусу от %2.</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Удаленная папка восстановлена</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Изменено имя или описание библиотеки</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation>Авто слияние с %1 системой</translation>
    </message>
    <message>
        <source>Just now</source>
        <translation>Только что</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>1 день назад</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>%1 день назад</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 час назад</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 час назад</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>1 минуту назад</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 минуту назад</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Папка</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>Папка только для чтения</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Документ</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>PDF документ</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>Текстовый документ</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>Аудио файл</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Видео файл</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Word документ</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>PowerPoint документ</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Excel документ</translation>
    </message>
    <message>
        <source>%1 Client is already running</source>
        <translation>%1 уже запущен</translation>
    </message>
    <message>
        <source>Choose the disk letter for %1</source>
        <translation>Выберите букву диска для %1</translation>
    </message>
    <message>
        <source>Update to file %1 denied by folder permission setting</source>
        <translation>Обновление файла %1 запрещено настройкой разрешений для папки</translation>
    </message>
    <message>
        <source>Path %1 ends with space or period character</source>
        <translation>Путь %1 заканчивается символом пробела или точки</translation>
    </message>
    <message>
        <source>Path %1 contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation>Путь %1 содержит недопустимые символы, такие как &apos;|&apos; или &apos;:&apos;</translation>
    </message>
    <message>
        <source>Created or updated a file %1 in a non-writable library or folder</source>
        <translation>Создан или обновлен файл %1 в недоступной для записи библиотеке или папке</translation>
    </message>
    <message>
        <source>Concurrent updates to file %1. File is saved as conflict file</source>
        <translation>Одновременные обновления файла %1. Файл сохранен как файл конфликта</translation>
    </message>
    <message>
        <source>%1 is not added to a library and will not be uploaded</source>
        <translation>%1 не добавлен в библиотеку и не будет загружен</translation>
    </message>
    <message>
        <source>You can only move files/folders within a library or from one library to another library</source>
        <translation>Вы можете перемещать файлы/папки только внутри библиотеки или из одной библиотеки в другую</translation>
    </message>
    <message>
        <source>Syncing is denied by cloud-only permission settings</source>
        <translation>Синхронизация запрещена настройками разрешений только для облака</translation>
    </message>
    <message>
        <source>Do not have write permission to the library</source>
        <translation>Нет разрешения на запись в библиотеку</translation>
    </message>
    <message>
        <source>Waiting for confirmation to delete files</source>
        <translation>Ожидание подтверждения удаления файлов</translation>
    </message>
    <message>
        <source>The path %1 contains symbols that are not supported by the Windows system.</source>
        <translation>Путь %1 содержит символы, не поддерживаемые системой Windows.</translation>
    </message>
    <message>
        <source>Failed to upload file blocks. Please check network or firewall.</source>
        <translation>Не удалось загрузить блоки файлов. Проверьте сеть или брандмауэр.</translation>
    </message>
    <message>
        <source>Failed to download file. Please check disk space or folder permissions</source>
        <translation>Не удалось скачать файл. Проверьте место на диске или права доступа к папке</translation>
    </message>
    <message>
        <source>Library cannot be synced since it has too many files.</source>
        <translation>Библиотека не может быть синхронизирована, так как в ней слишком много файлов.</translation>
    </message>
    <message>
        <source>Files cannot be uploaded to this library due to file number limit settings.</source>
        <translation>Файлы не могут быть загружены в эту библиотеку из-за настроек ограничения количества файлов.</translation>
    </message>
    <message>
        <source>Path has character case conflict with existing file or folder. Will not be downloaded</source>
        <translation>Путь конфликтует с регистром символов существующего файла или папки. Не будет загружен.</translation>
    </message>
    <message>
        <source>Failed to change library name since some files are opened in it</source>
        <translation>Не удалось изменить название библиотеки, так как в ней открыты некоторые файлы</translation>
    </message>
</context>
<context>
    <name>RemoteWipeService</name>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>Авторизация истекла. Пожалуйста, войдите снова</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login. You can find files that are not uploaded yet at ~/Library/CloudStorage</source>
        <translation>Срок действия авторизации истек, войдите повторно. Вы можете найти файлы, которые еще не загружены в ~/Library/CloudStorage</translation>
    </message>
</context>
<context>
    <name>SeaDriveRootDialog</name>
    <message>
        <source>Choose SeaDrive Cache Folder</source>
        <translation> Выберите папку для кэша SeaDrive</translation>
    </message>
    <message>
        <source>Your files will appear in a local cache folder. Please choose the folder:</source>
        <translation>Ваши файлы появятся в папке локального кэша. Выберите папку:</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>выбрать...</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Choose %1 Cache Folder </source>
        <translation>Выберите папку для кэша %1</translation>
    </message>
    <message>
        <source>Choose %1 Cache Folder</source>
        <translation>Выберите папку для кэша %1</translation>
    </message>
    <message>
        <source>Please choose %1 cache folder</source>
        <translation>Выберите папку для кэша %1</translation>
    </message>
    <message>
        <source>Create %1 folder failed!</source>
        <translation>Не удалось создать папку %1!</translation>
    </message>
</context>
<context>
    <name>SeadriveGui</name>
    <message>
        <source>Failed to initialize log: %1</source>
        <translation>Не удалось инициализировать журнал: %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>failed to save client id</source>
        <translation>не удалось сохранить ID клиента</translation>
    </message>
    <message>
        <source>failed to access %1</source>
        <translation>нет доступа к %1</translation>
    </message>
    <message>
        <source>incorrect client id</source>
        <translation>Неверный ID клиента</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>Ошибка чтения %1</translation>
    </message>
    <message>
        <source>Auto logon failed, fall back to manual login</source>
        <translation>Автоматический вход не выполнен, вернитесь к ручному входу</translation>
    </message>
    <message>
        <source>Faild to choose a cache directory</source>
        <translation>Не удалось выбрать папку для кэша</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 folder</source>
        <translation>Не удалось инициализировать: не удалось создать папку %1</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 logs folder</source>
        <translation>Не удалось инициализировать: не удалось создать папку для логов %1</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 data folder</source>
        <translation>Не удалось инициализировать: не удалось создать папку для данных %1</translation>
    </message>
    <message>
        <source>Failed to create seadrive cache directory</source>
        <translation>Не удалось создать папку для кэша Seadrive</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Faild to migrate old data</source>
        <translation>Не удалось перенести старые данные</translation>
    </message>
    <message>
        <source>SeaDrive %1 with multiple accounts cannot work with macOS version lower than 14.4. Please upgrade your macOS or downgrade SeaDrive to 3.0.9</source>
        <translation>SeaDrive %1 с несколькими учетными записями не может работать с macOS версии ниже 14.4. Обновите macOS или понизьте версию SeaDrive до 3.0.9</translation>
    </message>
    <message>
        <source>To start %1 extension for account %2, you need to click the %3 entry in Finder</source>
        <translation>Чтобы запустить расширение %1 для учетной записи %2, вам нужно щелкнуть запись %3 в Finder</translation>
    </message>
</context>
<context>
    <name>SeafileExtensionHandler</name>
    <message>
        <source>Failed to get upload link information for file &quot;%1&quot;</source>
        <translation>Не удалось получить информацию о ссылке для загрузки файла &quot;%1&quot;</translation>
    </message>
    <message>
        <source>No permissions to create a shared link</source>
        <translation>Нет прав на создание общедоступной ссылки</translation>
    </message>
    <message>
        <source>failed get internal link %1</source>
        <translation>не удалось получить внутреннюю ссылку %1</translation>
    </message>
    <message>
        <source>Failed to lock file</source>
        <translation>Не удалось заблокировать файл</translation>
    </message>
    <message>
        <source>Failed to unlock file</source>
        <translation>Не удалось разблокировать файл</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; is locked by %2</source>
        <translation>Файл &quot;%1&quot; заблокирован %2</translation>
    </message>
    <message>
        <source>Failed to get lock information for file &quot;%1&quot;</source>
        <translation>Не удалось получить информацию о блокировке файла &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to get share link %1
</source>
        <translation>Не удалось получить общедоступную ссылку %1
</translation>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation>%1 Внутренняя ссылка</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копировать в буфер обмена</translation>
    </message>
    <message>
        <source>%1 Internal Link:</source>
        <translation>%1 Внутренняя ссылка:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>internal error: failed to connect to %1 daemon</source>
        <translation>внутренняя ошибка: не удалось подключиться к демону %1</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation>Показать ошибки синхронизации файлов</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>Открыть папку с &amp;логами</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>О &amp;программе</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Показать окно About</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Онлайн справка</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation>Учетные записи</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>не зарегистрирован</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Добавить учетную запись</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Seafile Drive Client %2&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Seafile Drive Client&lt;/h2&gt;
Версия:  %2</translation>
    </message>
    <message>
        <source>Up %1, Down %2</source>
        <translation>Прием: %1, Отдача: %2</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>О программе %1</translation>
    </message>
    <message>
        <source>Transfer progress</source>
        <translation>Перенос передачи</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>открыть папку %1 с логами</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>открыть %1 онлайн справку</translation>
    </message>
    <message>
        <source>Show encrypted libraries</source>
        <translation>Показать зашифрованные библиотеки</translation>
    </message>
    <message>
        <source>Starting ...</source>
        <translation>Запуск ...</translation>
    </message>
    <message>
        <source>Resync</source>
        <translation>Повторная синхронизация</translation>
    </message>
    <message>
        <source>There are changes being uploaded under the account, please try again later</source>
        <translation>Под учетной записью загружаются изменения, повторите попытку позже</translation>
    </message>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? After removing account, you can still find downloaded files at ~/Library/CloudStorage.</source>
        <translation>Вы уверены, что хотите удалить аккаунт из &quot;%1&quot;? После удаления аккаунта вы по-прежнему сможете найти загруженные файлы в ~/Library/CloudStorage.</translation>
    </message>
    <message>
        <source>Failed to connect to background process, please try again later</source>
        <translation>Не удалось подключиться к фоновому процессу. Повторите попытку позже.</translation>
    </message>
    <message>
        <source>SeaDrive %1 with multiple accounts cannot work with macOS version lower than 14.4. Please upgrade your macOS or downgrade SeaDrive to 3.0.9</source>
        <translation>SeaDrive %1 с несколькими учетными записями не может работать с macOS версии ниже 14.4. Обновите macOS или понизьте версию SeaDrive до 3.0.9</translation>
    </message>
    <message>
        <source>Search files</source>
        <translation>Поиск файлов</translation>
    </message>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
        <translation>Вы уверены, что необходимо удалить учетную запись с &quot;%1&quot;? Скачанные и загружаемые файлы не будут удалены.</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
        <translation>Вы уверены, что необходимо повторно синхронизировать учетную запись с &quot;%1&quot;? Скачанные и загружаемые файлы не будут удалены.</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? After resyncing account, you can still find downloaded files at ~/Library/CloudStorage.</source>
        <translation>Вы уверены, что необходимо повторно синхронизировать учетную запись с &quot;%1&quot;? После повторной синхронизации учетной записи вы по-прежнему можете найти загруженные файлы в ~/Library/CloudStorage.</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search files</source>
        <translation>Поиск файлов</translation>
    </message>
    <message>
        <source>All file types</source>
        <translation>Все типы файлов</translation>
    </message>
    <message>
        <source>Custom file type</source>
        <translation>Пользовательский тип файла</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>повторить</translation>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation>Не удалось найти&lt;br/&gt;Пожалуйста, %1</translation>
    </message>
    <message>
        <source>No result found</source>
        <translation>Ничего не найдено</translation>
    </message>
</context>
<context>
    <name>SearchItemsTableModel</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>Вид</translation>
    </message>
</context>
<context>
    <name>SearchItemsTableView</name>
    <message>
        <source>&amp;Open the file</source>
        <translation>&amp;Открыть файл</translation>
    </message>
    <message>
        <source>&amp;Show in folder</source>
        <translation>&amp;Показать в папке</translation>
    </message>
    <message>
        <source>File not found, maybe not synchorized yet</source>
        <translation>Файл не найден, возможно, не синхронизирован</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation>Автоматически запускать %1 после входа в систему</translation>
    </message>
    <message>
        <source>Cache directory:</source>
        <translation>Каталог для кэша:</translation>
    </message>
    <message>
        <source>Enable search</source>
        <translation>Включить поиск</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP прокси</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Socks5 прокси</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системный прокси</translation>
    </message>
    <message>
        <source>enabled search</source>
        <translation>поиск включен</translation>
    </message>
    <message>
        <source>disabled search</source>
        <translation>поиск отключен</translation>
    </message>
    <message>
        <source>You have %1. Restart to apply it?</source>
        <translation>Вы %1. Перезапустить приложение сейчас?</translation>
    </message>
    <message>
        <source>Please choose the cache folder</source>
        <translation>Пожалуйста, выберите папку для кэша</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation>Хост прокси не может быть пустым</translation>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation>Порт прокси неправильный</translation>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation>Имя пользователя прокси не может быть пустым</translation>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation>Пароль прокси не может быть пустым</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Диалог</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Уведомить о синхронизации библиотек</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Синхронизировать временные файлы MSOffice/Libreoffice</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Ограничение скорости скачивания (КБ/с):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Ограничение скорости загрузки (КБ/с):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Основной</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>Включить расширение Explorer</translation>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>Не проверять сертификат сервера при HTTPS синхронизации</translation>
    </message>
    <message>
        <source>Cache clean interval (in minutes):</source>
        <translation>Интервал очистки кэша (в мин.):</translation>
    </message>
    <message>
        <source>Cache size limit (in GB):</source>
        <translation>Размер кэша (в Гб):</translation>
    </message>
    <message>
        <source>select...</source>
        <translation>выбрать...</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Дополнительно</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Язык (необходим перезапуск)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Тип прокси:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>Прокси сервер требует пароль</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Enable search in finder</source>
        <translation>Включить поиск в найденном</translation>
    </message>
    <message>
        <source>You have changed language, Restart to apply it?</source>
        <translation>Вы изменили язык, перезапустить, чтобы применить изменения?</translation>
    </message>
    <message>
        <source>You have changed cache directory. Restart to apply it?</source>
        <translation>Вы изменили папку для кэша. Перезапустить, чтобы применить изменения?</translation>
    </message>
    <message>
        <source>You have changed %1 cache folder. Restart to apply it?</source>
        <translation>Вы изменили папку для кэша %1. Перезагрузить, чтобы применить изменения?</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Hide Windows incompatibility paths Message</source>
        <translation>Скрыть сообщение о путях несовместимости Windows</translation>
    </message>
    <message>
        <source>Confirm before deleting files more than</source>
        <translation>Подтвердить удаление файлов более, чем</translation>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Ссылка</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Ссылка:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>Прямое скачивание</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копировать в буфер обмена</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Показать пароль</translation>
    </message>
    <message>
        <source>Expire days</source>
        <translation>Срок действия дней</translation>
    </message>
    <message>
        <source>Generate link</source>
        <translation>Создать ссылку</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Failed to generate share link: %1</source>
        <translation>Не удалось создать ссылку общего доступа: %1</translation>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Single Sign On</source>
        <translation>Единая точка входа</translation>
    </message>
</context>
<context>
    <name>SyncCommand</name>
    <message>
        <source>No permissions to create a shared link</source>
        <translation>Нет прав на создание общедоступной ссылки</translation>
    </message>
    <message>
        <source>failed to get share link %1</source>
        <translation>не удалось получить общедоступную ссылку %1</translation>
    </message>
    <message>
        <source>failed get internal link %1</source>
        <translation>не удалось получить внутреннюю ссылку %1</translation>
    </message>
    <message>
        <source>Failed to get upload link for file &quot;%1&quot;</source>
        <translation>Не удалось получить ссылку для загрузки файла &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation>Ошибки синхронизации файлов</translation>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation>Нет ошибок синхронизации.</translation>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation>Дважды щелкните, чтобы открыть библиотеку</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Путь</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Время</translation>
    </message>
</context>
<context>
    <name>TransferItemsTableModel</name>
    <message>
        <source>finished</source>
        <translation>завершено</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Передача</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Сервер</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
</context>
<context>
    <name>TransferProgressDialog</name>
    <message>
        <source>Transfer Progress</source>
        <translation>Перенос передачи</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Скачать</translation>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Удалить %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Вы хотите удалить информацию об аккаунте %1?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Удаление информации об аккаунте...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Диалог</translation>
    </message>
    <message>
        <source>text</source>
        <translation>текст</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Нет</translation>
    </message>
</context>
<context>
    <name>UploadLinkDialog</name>
    <message>
        <source>Upload Link</source>
        <translation>Ссылка для загрузки</translation>
    </message>
    <message>
        <source>Upload link:</source>
        <translation>Ссылка для загрузки:</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копировать в буфер обмена</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>